//
//  CPAPlugInsController.h
//  CocoaPacketAnalyzer
//
//  Created by franckej on 16.03.08.
//  Copyright Jens Francke. All rights reserved.
//

#import <Cocoa/Cocoa.h>

typedef enum {
    kCPAProtocolNone        = -1,
    kCPAProtocolTCP         = 0,
    kCPAProtocolUDP         = 1,
    kCPAProtocolUDPandTCP   = 100
}kCPASourceProtocols;

#define CPAFindPredicateDisplayName	    @"CPAFindPredicateDisplayName"
#define CPAFindPredicateLeftExpression	    @"CPAFindPredicateLeftExpression"
#define CPAFindPredicateAttrType	    @"CPAFindPredicateAttrType"

@interface CPAPlugInsController : NSObject {

}


+ (CPAPlugInsController *) sharedPlugInsController;

/* register the plugin preference instance */
- (BOOL) registerPluginPreferencesInstance:(id)aPreferencesInstance forPlugin:(NSBundle *)thePluginBundle;

/* register the plugin analyzer class */
- (BOOL) registerAnalyzerClass:(Class)anAnalyzerClass forPlugin:(NSBundle *)thePluginBundle;

/*  register/unregister a protocol for port based analysis, possibly values for sourceProtocol are: kCPAProtocolNone, kCPAProtocolTCP, kCPAProtocolUDP, kCPAProtocolUDPandTCP
    if port is nil and sourceProtocol is kCPAProtocolNone the analyzer is used for non port based protocol analysis (e.g. Ethertypes, IP-Protocols, PPP-Protocols...) 
    This will also update the description in the preferences.
 */
- (BOOL) registerProtocol:(NSString *)aProtocol port:(NSNumber *)aPort sourceProtocol:(int8_t)aSourceProtocol forPlugin:(NSBundle *)thePluginBundle;
- (BOOL) unregisterProtocol:(NSString *)aProtocol port:(NSNumber *)aPort sourceProtocol:(int8_t)aSourceProtocol forPlugin:(NSBundle *)thePluginBundle;

/* register a table column for the packet view */
- (BOOL) registerTableColumn:(NSTableColumn *)aColumn keyPath:(NSString *)aKeyPath bindingOptions:(NSDictionary *)theOptions forPlugin:(NSBundle *)thePluginBundle;

/* register a predicate for the search */
- (BOOL) registerPredicateOption:(NSDictionary *)predicateOptionDictionary forPlugin:(NSBundle *)thePluginBundle;

/* get an analyzer class for a protocol */
- (Class) analyzerClassForProtocol:(NSString *)aProtocol;

@end
